@@ -60,21 +60,49 @@ sub make_feed {
     my ($self, %args) = @_;
     
     my $feed_type = $args{feed_type};
+    my $feed_listing = $args{feed_listing};
     
-    my %known_types = (
-                          'rss'  => 1,
-                          'atom' => 1,
-                      );
+    my %known_listings = (
+                          'recent_changes' => 1,
+                          'node_all_versions' => 1,
+                         );
                       
+    croak "No feed listing specified" unless $feed_listing;
+    croak "Unknown feed listing: $feed_listing" unless $known_listings{$feed_listing};
+
+    # Fetch the right Wiki::Toolkit::Feeds::Listing instance to use
+    my $maker = $self->fetch_maker($feed_type);
+
+    # Call the appropriate feed listing from it
+    if ($feed_listing eq 'recent_changes') {
+        return $maker->recent_changes(%args);
+    }
+    elsif ($feed_listing eq 'node_all_versions') {
+        return $maker->node_all_versions(%args);
+    }
+}
+
+=item B<fetch_maker>
+For the given feed type, identify and return the maker routine for feeds
+of that type. 
+
+my $maker = $feed->fetch_maker("rss");
+my $feed_contents = maker->node_all_versions(%options);
+
+Will always return something of type Wiki::Toolkit::Feed::Listing
+=cut
+sub fetch_maker {
+    my ($self,$feed_type) = @_;
+
+    my %known_types = (
+                          'rss'  => \&atom_maker,
+                          'atom' => \&rss_maker,
+                      );
+
     croak "No feed type specified" unless $feed_type;
     croak "Unknown feed type: $feed_type" unless $known_types{$feed_type};
 
-    if ($feed_type eq 'rss') {
-        return $self->rss_maker->recent_changes(%args);
-    }
-    elsif ($feed_type eq 'atom') {
-        return $self->atom_maker->recent_changes(%args);
-    }
+    return &{$known_types{$feed_type}};
 }
 
 sub atom_maker {
@@ -121,8 +149,9 @@ sub rss_maker {
 sub feed_timestamp {
     my ($self, %args) = @_;
 
-    # The timestamp methods in our feeds are equivalent, we might as well
-    # use the RSS one.
+    # Call the compatability timestamping method on the RSS Feed.
+    # People should really just pass in also_return_timestamp to the
+    #  feed method, and get the timestamp at the same time as their data
     $self->rss_maker->rss_timestamp(%args);
 }
 
@@ -150,11 +179,14 @@ developers.
                                       og_version => '1.0', ); 
 
     # Ten most recent changes in RSS format.
-    print "Content-Type: application/rdf+xml\n";
-    print "Last-Modified: " . $self->feed_timestamp( items => 10 ) . "\n\n";
     my %args = ( items     => 10,
-                 feed_type => 'rss', );
-    print $feed->make_feed( %args );
+                 feed_type => 'rss', 
+                 also_return_timestamp => 1 );
+    my ($feed_output,$feed_timestamp) = $feed->make_feed( %args );
+
+    print "Content-Type: application/rdf+xml\n";
+    print "Last-Modified: " . $feed_timestamp . "\n\n";
+    print $feed_output;
 
 =head1 METHODS
 
@@ -184,30 +216,42 @@ invoked this module with.
 =item B<make_feed>
 
     # Ten most recent changes in RSS format.
-    print "Content-Type: application/rdf+xml\n";
-    print "Last-Modified: " . $feed->feed_timestamp( items => 10 ) . "\n\n";
     my %args = ( items     => 10,
-                 feed_type => 'rss', );
+                 feed_type => 'rss',
+                 also_return_timestamp => 1 );
+    my ($feed_output,$feed_timestamp) = $rdf_writer->make_feed( %args );
+
+    print "Content-Type: application/rdf+xml\n";
+    print "Last-Modified: " . $feed_timestamp . "\n\n";
+    print $feed_output;
     print $rdf_writer->make_feed( %args );
 
+
     # All the changes made by bob in the past week, ignoring minor edits, in Atom.
     $args{days}               = 7;
     $args{ignore_minor_edits  = 1;
     $args{filter_on_metadata} => { username => "bob" };
+    $args{also_return_timestamp} => 1;
 
+    my ($feed_output,$feed_timestamp) = $rdf_writer->make_feed( %args );
     print "Content-Type: application/atom+xml\n";
-    print "Last-Modified: " . $feed->feed_timestamp( %args ) . "\n\n";
-    print $feed->make_feed( %args );
+    print "Last-Modified: " . $feed_timestamp . "\n\n";
+    print $feed_output;
 
 =item B<feed_timestamp>
 
+Instead of calling this, you should instead pass in the 'also_return_timestamp'
+option. You will then get back the feed timestamp, along with the feed output.
+
+This method will be removed in future, and currently will only return
+meaningful values if your arguments relate to recent changes.
+
     print "Last-Modified: " . $feed->feed_timestamp( %args ) . "\n\n";
 
-Returns the timestamp of the data feed in POSIX::strftime style ("Tue, 29 Feb 2000 
-12:34:56 GMT"), which is equivalent to the timestamp of the most recent item
-in the feed. Takes the same arguments as make_recentchanges_rss(). You will most 
-likely need this to print a Last-Modified HTTP header so user-agents can determine
-whether they need to reload the feed or not.
+Returns the timestamp of something in POSIX::strftime style ("Tue, 29 Feb 2000 
+12:34:56 GMT"). Takes the same arguments as make_recentchanges_rss(). 
+You will most likely need this to print a Last-Modified HTTP header so 
+user-agents can determine whether they need to reload the feed or not.
 
 =back
 
